import { supabase } from "@/lib/auth/auth";

interface ProfileData {
  fullName: string;
  email: string;
  phone?: string;
  education?: string;
  bio?: string;
}

export async function updateProfile(data: ProfileData) {
  try {
    const { data: { session }, error: sessionError } = await supabase.auth.getSession();
    if (sessionError) throw sessionError;
    if (!session?.user?.id) throw new Error("No user found");

    const { error } = await supabase
      .from("profiles")
      .upsert({
        id: session.user.id,
        full_name: data.fullName,
        email: data.email,
        phone: data.phone,
        education: data.education,
        bio: data.bio,
        updated_at: new Date().toISOString(),
      }, {
        onConflict: 'id'
      });

    if (error) throw error;
  } catch (error: any) {
    console.error("Failed to update profile:", error);
    throw new Error(error.message || "Failed to update profile");
  }
}

export async function uploadProfilePicture(file: File) {
  try {
    const { data: { session }, error: sessionError } = await supabase.auth.getSession();
    if (sessionError) throw sessionError;
    if (!session?.user?.id) throw new Error("No user found");

    const fileExt = file.name.split(".").pop();
    const fileName = `${session.user.id}-${Date.now()}.${fileExt}`;

    // Delete old avatar if exists
    const { data: profile } = await supabase
      .from("profiles")
      .select("avatar_url")
      .eq("id", session.user.id)
      .single();

    if (profile?.avatar_url) {
      await supabase.storage
        .from("avatars")
        .remove([profile.avatar_url]);
    }

    // Upload new avatar
    const { error: uploadError } = await supabase.storage
      .from("avatars")
      .upload(fileName, file, {
        cacheControl: "3600",
        upsert: false
      });

    if (uploadError) throw uploadError;

    // Update profile with new avatar URL
    const { error: updateError } = await supabase
      .from("profiles")
      .update({ avatar_url: fileName })
      .eq("id", session.user.id);

    if (updateError) throw updateError;

    return fileName;
  } catch (error: any) {
    console.error("Failed to upload profile picture:", error);
    throw new Error(error.message || "Failed to upload profile picture");
  }
}